@@ -15,10 +15,10 @@
  */
 package org.pf4j.test;
 
-import java.io.ByteArrayOutputStream;
+import com.google.common.io.ByteStreams;
+
 import java.io.IOException;
 import java.io.InputStream;
-import java.io.OutputStream;
 
 /**
  * Get class data from the class path.
@@ -35,20 +35,10 @@ public class DefaultClassDataProvider implements ClassDataProvider {
             throw new RuntimeException("Cannot find class data");
         }
 
-        try (ByteArrayOutputStream outputStream = new ByteArrayOutputStream()) {
-            copyStream(classDataStream, outputStream);
-            return outputStream.toByteArray();
+        try {
+            return ByteStreams.toByteArray(classDataStream);
         } catch (IOException e) {
-            throw new RuntimeException(e.getMessage(), e);
-        }
-    }
-
-    private void copyStream(InputStream in, OutputStream out) throws IOException {
-        byte[] buffer = new byte[1024];
-
-        int bytesRead;
-        while ((bytesRead = in.read(buffer)) != -1) {
-            out.write(buffer, 0, bytesRead);
+            throw new IllegalStateException(e);
         }
     }
 
