@@ -12,11 +12,11 @@ rm -fr demo-dist
 mkdir -p demo-dist/plugins
 
 # copy artifacts to demo-dist folder
-cp demo/app/target/pf4j-demo-*.zip demo-dist/
-cp demo/plugins/plugin1/target/pf4j-demo-plugin1-*-all.jar demo-dist/plugins/
-cp demo/plugins/plugin2/target/pf4j-demo-plugin2-*-all.jar demo-dist/plugins/
-cp demo/plugins/enabled.txt demo-dist/plugins/
-cp demo/plugins/disabled.txt demo-dist/plugins/
+cp demo/maven/app/target/pf4j-demo-*.zip demo-dist/
+cp demo/maven/plugins/plugin1/target/pf4j-demo-plugin1-*-all.jar demo-dist/plugins/
+cp demo/maven/plugins/plugin2/target/pf4j-demo-plugin2-*-all.jar demo-dist/plugins/
+cp demo/maven/plugins/enabled.txt demo-dist/plugins/
+cp demo/maven/plugins/disabled.txt demo-dist/plugins/
 
 cd demo-dist
 
